local _, ns = ...

local _G = _G
ns.Locales = {}
local Locales = ns.Locales
local setfenv = _G.setfenv
setfenv(1, Locales)

local assert = _G.assert
local type = _G.type
local pairs = _G.pairs
local string, tostring, reverse, sub = _G.string, _G.tostring, _G.string.reverse, _G.string.sub
local abs, floor = _G.math.abs, _G.math.floor

local template = {}

function template:formatInteger(number)
    local strNumber = tostring(number)
    local first = sub(strNumber, 1, 1)
    local middle = sub(strNumber, 2)
    local revMiddle = reverse(middle)
    local strNumberFormatted = first .. revMiddle:gsub('(%d%d%d)','%1' .. self.digitSeperator):reverse()
    return strNumberFormatted
end

function template:formatNumber(number)
    assert(type(number) == 'number', "'number' is not a number but a " .. type(number))
    local absValue = abs(number)
    local sign = number > 0 and 1 or (number < 0 and -1 or 0)
    local integerPart = floor(absValue)
    local strIntegerPartFormatted = self:formatInteger(integerPart)
    local fractionalPart = absValue - integerPart
    local strFractionalPartFormatted = ''
    if fractionalPart > 1e-2 then
        local strFractionalPart = sub(tostring(fractionalPart), 3)
        strFractionalPartFormatted = self.decimalSeperator .. strFractionalPart
    end
    local strSign = sign < 0 and '-' or ''
    local result = strSign .. strIntegerPartFormatted .. strFractionalPartFormatted
    --_G.ChatFrame3:AddMessage(number .. '=>' .. result)
    return result
end

local function copy(table)
    local result = {}
    for k,v in pairs(table) do
        result[k]=v
    end
    return result
end

Locales.userLocale = copy(template)

Locales.userLocale.digitSeperator = '.'
Locales.userLocale.decimalSeperator = ','

function Locales:getUserLocale()
    return self.userLocale
end